@@ -6,6 +6,7 @@ from pathlib import Path
 from invoke import task
 
 from dbt_invoke.internal import _utils
+import ast
 
 _LOGGER = _utils.get_logger('dbt-invoke')
 _MACRO_NAME = '_log_columns_list'
@@ -502,13 +503,21 @@ def _get_columns(ctx, resource_location, resource_dict, **kwargs):
         result_lines = _utils.dbt_run_operation(
             ctx, _MACRO_NAME, hide=True, logger=_LOGGER, sql=sql, **kwargs
         )
-    result_list_strings = [
-        s for s in result_lines if s.startswith('[') and s.endswith(']')
-    ]
-    # Take the last line that started with '[' and ended with ']'
-    # (just in case there is multi-line output)
-    columns_string = result_list_strings[-1].strip('][').split(', ')
-    columns = [col.strip("'") for col in columns_string]
+
+    # from dbt-core v1.0.0 onwards, run_operations INFO logs have code M011 and messages have key 'msg'
+    # https://github.com/dbt-labs/dbt-core/blob/22b1a09aa218e8152b0c2dd261abe2503ea15ddb/core/dbt/events/types.py#L401
+    relevant_lines = list(
+        filter(lambda x: x.get('code') == 'M011', result_lines)
+    )
+    if len(relevant_lines) >= 1:
+        columns = relevant_lines[-1].get('msg')
+    else:
+        # for older dbt-core versions, we need to cross fingers a little harder
+        relevant_lines = result_lines[1:]
+        # also, the message key is different
+        columns = relevant_lines[-1].get('message')
+        # columns are not passed as valid json but as a string representation of a list
+        columns = ast.literal_eval(columns)
     return columns
 
 
